==> qtjambi-qt3dcore-debuginfo-macos-5.15.18.jar: sources/QtJambi3DCore/QNodeIdTypePair_shell.cpp <==
#include <QtCore/QtGlobal>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_Qt3DCore_QNodeIdTypePair(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QNodeIdTypePair")
    Qt3DCore::QNodeIdTypePair *_ptr = reinterpret_cast<Qt3DCore::QNodeIdTypePair *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QNodeIdTypePair()
void __qt_construct_Qt3DCore_QNodeIdTypePair_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNodeIdTypePair()")
    Q_UNUSED(__java_arguments)
    Qt3DCore::QNodeIdTypePair *__qt_this = new(__qtjambi_ptr) Qt3DCore::QNodeIdTypePair();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QNodeIdTypePair(Qt3DCore::QNodeId,const QMetaObject*)
void __qt_construct_Qt3DCore_QNodeIdTypePair_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNodeIdTypePair(Qt3DCore::QNodeId,const QMetaObject*)")
    jobject _id0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt__id0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, _id0);
    jobject _type1 = __java_arguments[1].l;
    const QMetaObject* __qt__type1 = qtjambi_cast<const QMetaObject*>(__jni_env, _type1);
    Qt3DCore::QNodeIdTypePair *__qt_this = new(__qtjambi_ptr) Qt3DCore::QNodeIdTypePair(__qt__id0, __qt__type1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct Qt3DCore::QNodeIdTypePair
void __qt_destruct_Qt3DCore_QNodeIdTypePair(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QNodeIdTypePair")
    reinterpret_cast<Qt3DCore::QNodeIdTypePair*>(ptr)->~QNodeIdTypePair();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QNodeIdTypePair::QNodeIdTypePair()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_initialize_1native__Lio_qt_qt3d_core_QNodeIdTypePair_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QNodeIdTypePair::QNodeIdTypePair()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QNodeIdTypePair_0, sizeof(Qt3DCore::QNodeIdTypePair), typeid(Qt3DCore::QNodeIdTypePair), false, &deleter_Qt3DCore_QNodeIdTypePair, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QNodeIdTypePair::QNodeIdTypePair(Qt3DCore::QNodeId,const QMetaObject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_initialize_1native__Lio_qt_qt3d_core_QNodeIdTypePair_2Lio_qt_qt3d_core_QNodeId_2Lio_qt_core_QMetaObject_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject _id0,
 jobject _type1)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QNodeIdTypePair::QNodeIdTypePair(Qt3DCore::QNodeId,const QMetaObject*)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = _id0;
        arguments[1].l = _type1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QNodeIdTypePair_1, sizeof(Qt3DCore::QNodeIdTypePair), typeid(Qt3DCore::QNodeIdTypePair), false, &deleter_Qt3DCore_QNodeIdTypePair, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_setId_1native_1cref_1Qt3DCore_1QNodeId__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID id0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        Qt3DCore::QNodeIdTypePair *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeIdTypePair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt3DCore::QNodeId& __qt_id0 = QtJambiAPI::valueReferenceFromNativeId<Qt3DCore::QNodeId>(id0);
        __qt_this->id = __qt_id0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_id_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        Qt3DCore::QNodeIdTypePair *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeIdTypePair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt3DCore::QNodeId&  __qt_value = __qt_this->id;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_setType_1native_1const_1QMetaObject_1ptr__JLio_qt_core_QMetaObject_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject type0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        Qt3DCore::QNodeIdTypePair *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeIdTypePair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QMetaObject* __qt_type0 = qtjambi_cast<const QMetaObject*>(__jni_env, type0);
        __qt_this->type = __qt_type0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        Qt3DCore::QNodeIdTypePair *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeIdTypePair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QMetaObject*  __qt_value = __qt_this->type;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const Qt3DCore::QNodeIdTypePair *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeIdTypePair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_Qt3DCore_QNodeIdTypePair(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<Qt3DCore::QNodeIdTypePair>("Qt3DCore::QNodeIdTypePair", "io/qt/qt3d/core/QNodeIdTypePair");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QNodeIdTypePair, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QNodeIdTypePair_0, nullptr)
       ,ConstructorInfo(&__qt_construct_Qt3DCore_QNodeIdTypePair_1, "Lio/qt/qt3d/core/QNodeId;Lio/qt/core/QMetaObject;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QNodeIdTypePair);
    registerMetaType<Qt3DCore::QNodeIdTypePair>("Qt3DCore::QNodeIdTypePair");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-macos-5.15.20.jar: sources/QtJambi3DCore/QNodeIdTypePair_shell.cpp <==
#include <QtCore/QtGlobal>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_Qt3DCore_QNodeIdTypePair(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QNodeIdTypePair")
    Qt3DCore::QNodeIdTypePair *_ptr = reinterpret_cast<Qt3DCore::QNodeIdTypePair *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QNodeIdTypePair()
void __qt_construct_Qt3DCore_QNodeIdTypePair(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNodeIdTypePair()")
    Q_UNUSED(__java_arguments)
    Qt3DCore::QNodeIdTypePair *__qt_this = new(__qtjambi_ptr) Qt3DCore::QNodeIdTypePair();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QNodeIdTypePair::QNodeIdTypePair()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_initialize_1native__Lio_qt_qt3d_core_QNodeIdTypePair_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QNodeIdTypePair::QNodeIdTypePair()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QNodeIdTypePair, sizeof(Qt3DCore::QNodeIdTypePair), typeid(Qt3DCore::QNodeIdTypePair), false, &deleter_Qt3DCore_QNodeIdTypePair, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QNodeIdTypePair(Qt3DCore::QNodeId,const QMetaObject*)
void __qt_construct_Qt3DCore_QNodeIdTypePair_Qt3DCore_QNodeId_const_QMetaObject_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNodeIdTypePair(Qt3DCore::QNodeId,const QMetaObject*)")
    jobject _id0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt__id0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, _id0);
    jobject _type1 = __java_arguments[1].l;
    const QMetaObject* __qt__type1 = qtjambi_cast<const QMetaObject*>(__jni_env, _type1);
    Qt3DCore::QNodeIdTypePair *__qt_this = new(__qtjambi_ptr) Qt3DCore::QNodeIdTypePair(__qt__id0, __qt__type1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QNodeIdTypePair::QNodeIdTypePair(Qt3DCore::QNodeId,const QMetaObject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_initialize_1native__Lio_qt_qt3d_core_QNodeIdTypePair_2Lio_qt_qt3d_core_QNodeId_2Lio_qt_core_QMetaObject_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject _id0,
 jobject _type1)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QNodeIdTypePair::QNodeIdTypePair(Qt3DCore::QNodeId,const QMetaObject*)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = _id0;
        arguments[1].l = _type1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QNodeIdTypePair_Qt3DCore_QNodeId_const_QMetaObject_ptr, sizeof(Qt3DCore::QNodeIdTypePair), typeid(Qt3DCore::QNodeIdTypePair), false, &deleter_Qt3DCore_QNodeIdTypePair, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QNodeIdTypePair(Qt3DCore::QNodeIdTypePair)
void __qt_construct_Qt3DCore_QNodeIdTypePair_cref_Qt3DCore_QNodeIdTypePair(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNodeIdTypePair(Qt3DCore::QNodeIdTypePair)")
    jobject other0 = __java_arguments[0].l;
    const Qt3DCore::QNodeIdTypePair& __qt_other0 = qtjambi_cast<const Qt3DCore::QNodeIdTypePair& >(__jni_env, other0);
    Qt3DCore::QNodeIdTypePair *__qt_this = new(__qtjambi_ptr) Qt3DCore::QNodeIdTypePair(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QNodeIdTypePair::QNodeIdTypePair(Qt3DCore::QNodeIdTypePair)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_initialize_1native__Lio_qt_qt3d_core_QNodeIdTypePair_2Lio_qt_qt3d_core_QNodeIdTypePair_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QNodeIdTypePair::QNodeIdTypePair(Qt3DCore::QNodeIdTypePair)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QNodeIdTypePair_cref_Qt3DCore_QNodeIdTypePair, sizeof(Qt3DCore::QNodeIdTypePair), typeid(Qt3DCore::QNodeIdTypePair), false, &deleter_Qt3DCore_QNodeIdTypePair, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct Qt3DCore::QNodeIdTypePair
void __qt_destruct_Qt3DCore_QNodeIdTypePair(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QNodeIdTypePair")
    reinterpret_cast<Qt3DCore::QNodeIdTypePair*>(ptr)->~QNodeIdTypePair();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_setId_1native_1cref_1Qt3DCore_1QNodeId__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID id0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        Qt3DCore::QNodeIdTypePair *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeIdTypePair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt3DCore::QNodeId& __qt_id0 = QtJambiAPI::valueReferenceFromNativeId<Qt3DCore::QNodeId>(id0);
        __qt_this->id = __qt_id0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_id_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        Qt3DCore::QNodeIdTypePair *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeIdTypePair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt3DCore::QNodeId&  __qt_value = __qt_this->id;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_setType_1native_1const_1QMetaObject_1ptr__JLio_qt_core_QMetaObject_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject type0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        Qt3DCore::QNodeIdTypePair *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeIdTypePair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QMetaObject* __qt_type0 = qtjambi_cast<const QMetaObject*>(__jni_env, type0);
        __qt_this->type = __qt_type0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        Qt3DCore::QNodeIdTypePair *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeIdTypePair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QMetaObject*  __qt_value = __qt_this->type;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeIdTypePair_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const Qt3DCore::QNodeIdTypePair *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeIdTypePair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_Qt3DCore_QNodeIdTypePair(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<Qt3DCore::QNodeIdTypePair>("Qt3DCore::QNodeIdTypePair", "io/qt/qt3d/core/QNodeIdTypePair");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QNodeIdTypePair, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QNodeIdTypePair, nullptr)
       ,ConstructorInfo(&__qt_construct_Qt3DCore_QNodeIdTypePair_Qt3DCore_QNodeId_const_QMetaObject_ptr, "Lio/qt/qt3d/core/QNodeId;Lio/qt/core/QMetaObject;")
       ,ConstructorInfo(&__qt_construct_Qt3DCore_QNodeIdTypePair_cref_Qt3DCore_QNodeIdTypePair, "Lio/qt/qt3d/core/QNodeIdTypePair;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QNodeIdTypePair);
    registerMetaType<Qt3DCore::QNodeIdTypePair>("Qt3DCore::QNodeIdTypePair");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
